.. _multi_physics-examples-index:

multi_physics
=============

.. toctree::
   :maxdepth: 2

   biot.py <multi_physics-biot>
   biot_npbc.py <multi_physics-biot_npbc>
   biot_npbc_lagrange.py <multi_physics-biot_npbc_lagrange>
   biot_parallel_interactive.py <multi_physics-biot_parallel_interactive>
   biot_short_syntax.py <multi_physics-biot_short_syntax>
   piezo_elasticity.py <multi_physics-piezo_elasticity>
   piezo_elasticity_macro.py <multi_physics-piezo_elasticity_macro>
   piezo_elasticity_micro.py <multi_physics-piezo_elasticity_micro>
   piezo_elastodynamic.py <multi_physics-piezo_elastodynamic>
   thermal_electric.py <multi_physics-thermal_electric>
   thermo_elasticity.py <multi_physics-thermo_elasticity>
   thermo_elasticity_ess.py <multi_physics-thermo_elasticity_ess>
